--------------------------------------------------------
-- Bloodlust RaidCooldowns - Options --
--------------------------------------------------------
local BLRCD = BLRCD
local AceConfig = LibStub("AceConfig-3.0") -- For the options panel
local AceConfigDialog = LibStub("AceConfigDialog-3.0") -- Also for options panel
local AceDB = LibStub("AceDB-3.0") -- Makes saving things really easy
local AceDBOptions = LibStub("AceDBOptions-3.0") -- More database options

function BLRCD:SetupOptions()
	BLRCD.options.args.profile = AceDBOptions:GetOptionsTable(BLRCD.db)
	
	AceConfig:RegisterOptionsTable("BLRCD", BLRCD.options, nil)
	
	BLRCD.optionsFrames = {}
	BLRCD.optionsFrames.general = AceConfigDialog:AddToBlizOptions("BLRCD", "Bloodlust RaidCooldowns", nil, "general")
	BLRCD.optionsFrames.cooldowns = AceConfigDialog:AddToBlizOptions("BLRCD", "Cooldown Settings", "Bloodlust RaidCooldowns", "cooldowns")
	BLRCD.optionsFrames.displaycfg = AceConfigDialog:AddToBlizOptions("BLRCD", "Display Settings", "Bloodlust RaidCooldowns", "displaycfg")
	BLRCD.optionsFrames.profile = AceConfigDialog:AddToBlizOptions("BLRCD", "Profiles", "Bloodlust RaidCooldowns", "profile")
end

BLRCD.TexCoords = {.08, .92, .08, .92}

BLRCD.defaults = {
	profile = {
		castannounce = false,
		cdannounce = false,
		clickannounce = false,
		warnannounce = false,
		minimap = {
			hide = false,
		},
		scale = 1,
		growth = "right",
		show = "raid",
		onlyshowinraid = true,
		filteradditionalpeople = false,
		display = {
			AOE_HEAL = true,
			SINGLE_HEAL = true,
			AOE_DPS = true,
			REZ = true,
			MANA_REGEN = true,
			MISC = true,
			DEFENSIVE = false,
			CD_BAR = true,
		},
		cooldown = {
			PAL_DA = true,
			PAL_HOS = true,
			PAL_LOH = true,
			PAL_HOPUR = true,
			PAL_HOPRO = true,
			PAL_DSHIELD = true,
			PRI_PWB = true,
			PRI_PS = true,
			PRI_DH = true,
			PRI_GS = true,
			PRI_VS = true,
			PRI_HH = true,
			PRI_VE = true,
			PRI_DPRAY = true,
			PRI_LWELL = true,
			PRI_SSHELL = true,
			PRI_PINF = true,
			PRI_DISP = true,
			DRU_TRANQ = true,
			DRU_FE = true,
			DRU_REZ = true,
			DRU_INNERV = true,
			DRU_BAR = true,
			DRU_MOU = true,
			DRU_RENEW = true,
			DRU_SI = true,
			SHA_SLT = true,
			SHA_MTT = true,
			SHA_HTT = true,
			SHA_ST = true,
			SHA_FET = true,
			SHA_RE = true,
			SHA_ASC = true,
			SHA_ASHIFT = true,
			SHA_SBTOT = true,
			SHA_SRAGE = true,
			MON_ZEN = true,
			MON_LIFE = true,
			MON_REV = true,
			MON_AHARM = true,
			MON_DHARM = true,
			MON_FBREW = true,
			MON_DMAG = true,
			MON_TOKAR = true,
			LOC_SR = true,
			LOC_TWARD = true,
			LOC_URESOLVE= true,
			LOC_DREGEN = true,
			LOC_DBARGAIN = true,
			LOC_SPACT = true,
			DEA_RA = true,
			DEA_AMZ = true,
			DEA_RW = true,
			DEA_GG = true,
			DEA_IBF = true,
			DEA_AOTD = true,
			DEA_AMS = true,
			DEA_DP = true,
			DEA_BS = true,
			DEA_DRW = true,
			DEA_RT = true,
			DEA_VB = true,
			WAR_RC = true,
			WAR_DB = true,
			WAR_STH = true,
			WAR_SB = true,
			WAR_VIGI = true,
			WAR_SGUARD = true,
			WAR_DSHOUT = true,
			WAR_SWALL = true,
			WAR_DBTW = true,
			WAR_LSTAND = true,
			WAR_EREGEN = true,
			ROG_SB = true,
			ROG_FEINT = true,
			ROG_TOT = true,
			MAG_AT = true,
			MAG_IBAR = true,
			MAG_TS = true,
			MAG_GI = true,
			MAG_IW = true,
			MAG_IB = true,
			HUN_EX = true,
			HUN_DET = true,
			ALL_HS = true
		},
		category = { },
	},
}

BLRCD.options =  {
	type = "group",
	name = "Bloodlust RaidCooldowns",
	args = {
		general = {
			order = 1,
			type = "group",
			name = "General Settings",
			cmdInline = true,
			args = {
				castannounce = {
					type = "toggle",
					name = "Announce Casts",
					order = 2,
					get = function()
						return BLRCD.profileDB.castannounce
					end,
					set = function(key, value)
						BLRCD.profileDB.castannounce = value
					end,
				},		
				cdannounce = {
					type = "toggle",
					name = "Announce CD Expire",
					order = 3,
					get = function()
						return BLRCD.profileDB.cdannounce
					end,
					set = function(key, value)
						BLRCD.profileDB.cdannounce = value
					end,
				},		
				onlyshowinraid = {
					type = "toggle",
					name = "Only show in party/raid",
					order = 6,
					get = function()
						return BLRCD.profileDB.onlyshowinraid
					end,
					set = function(key, value)
						BLRCD.profileDB.onlyshowinraid = value
						BLRCD:ShowHideFrames()
					end,
				},		
				configure = {
					order = 9,
					type = "execute",
					name = "Apply Changes",
					desc = "Apply the changes to the active cooldowns and reload the UI.",
					func = function()
						ReloadUI()
					end,
					order = 1,
					width = "full",
				},
				clickannounce = {
					type = "toggle",
					name = "Click to Announce Available",
					order = 10,
					get = function()
						return BLRCD.profileDB.clickannounce
					end,
					set = function(key, value)
						BLRCD.profileDB.clickannounce = value
					end,
				},
				warnannounce = {
					type = "toggle",
					name = "Raid Warning Announce (only if leader/assist)",
					order = 10,
					get = function()
						return BLRCD.profileDB.warnannounce
					end,
					set = function(key, value)
						BLRCD.profileDB.warnannounce = value
					end,
				},
				filteradditionalpeople = {
					type = "toggle",
					name = "Filter spare members (only show grp1-2 in 10man, grp1-5 in 25)",
					order = 11,
					get = function()
						return BLRCD.profileDB.filteradditionalpeople
					end,
					set = function(key, value)
						BLRCD.profileDB.filteradditionalpeople = value
					end,
				},
			},
		},
		cooldowns = {
			order = 2,
			type = "group",
			name = "Cooldown Settings",
			cmdInline = true,
			args = {
				configure = {
					type = "execute",
					name = "Apply Changes",
					desc = "Apply the changes to the active cooldowns and reload the UI.",
					func = function()
						ReloadUI()
					end,
					order = 1,
					width = "full",
				},
				paladin = {
					type = "group",
					name = "Paladin Cooldowns",
					order = 2,
					args ={
						PAL_DA = {
							type = "toggle",
							name = "Devotion Aura",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_DA
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_DA = value
							end,
						},
						PAL_HOS = {
							type = "toggle",
							name = "Hand of Sacrifice",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_HOS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_HOS = value
							end,
						},
						PAL_LOH = {
							type = "toggle",
							name = "Lay on Hands",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_LOH
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_LOH = value
							end,
						},
						PAL_HOPUR = {
							type = "toggle",
							name = "Lay on Hands",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_HOPUR
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_HOPUR = value
							end,
						},	
						PAL_LOH = {
							type = "toggle",
							name = "Lay on Hands",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_HOPRO
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_HOPRO = value
							end,
						},	
						PAL_DSHIELD = {
							type = "toggle",
							name = "Divine Shield",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_DSHIELD
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_DSHIELD = value
							end,
						},
						PAL_DPROT = {
							type = "toggle",
							name = "Divine Protection",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PAL_DPROT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PAL_DPROT = value
							end,
						},
					},
				},
				priest = {
					type = "group",
					name = "Priest Cooldowns",
					order = 2,
					args ={
						PRI_PWB = {
							type = "toggle",
							name = "Power Word: Barrier",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_PWB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_PWB = value
							end,
						},
						PRI_PS = {
							type = "toggle",
							name = "Pain Suppression",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_PS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_PS = value
							end,
						},		
						PRI_DH = {
							type = "toggle",
							name = "Divine Hymn",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_DH
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_DH = value
							end,
						},		
						PRI_GS = {
							type = "toggle",
							name = "Guardian Spirit",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_GS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_GS = value
							end,
						},		
						PRI_VS = {
							type = "toggle",
							name = "Void Shift",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_VS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_VS = value
							end,
						},
						PRI_HH = {
							type = "toggle",
							name = "Hymn Of Hope",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_HH
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_HH = value
							end,
						},							
						PRI_VE = {
							type = "toggle",
							name = "Vampiric Embrace",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_VE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_VE = value
							end,
						},
						PRI_LWELL = {
							type = "toggle",
							name = "Lightwell",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_LWELL
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_LWELL = value
							end,
						},
						PRI_SSHELL = {
							type = "toggle",
							name = "Spirit Shell",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_SSHELL
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_SSHELL = value
							end,
						},
						PRI_DPRAY = {
							type = "toggle",
							name = "Desperate Prayer",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_DPRAY
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_DPRAY = value
							end,
						},
						PRI_PINF = {
							type = "toggle",
							name = "Power Infusion",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_PINF
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_PINF = value
							end,
						},
						PRI_DISP = {
							type = "toggle",
							name = "Dispersion",
							order = 2,
							get = function()
								return BLRCD.profileDB.cooldown.PRI_DISP
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.PRI_DISP = value
							end,
						},
					},
				},
				druid = {
					type = "group",
					name = "Druid Cooldowns",
					order = 2,
					args ={
						DRU_TRANQ = {
							type = "toggle",
							name = "Tranquility",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_TRANQ
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_TRANQ = value
							end,
						},		
						DRU_FE = {
							type = "toggle",
							name = "Ironbark",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_FE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_FE = value
							end,
						},	
						DRU_REZ = {
							type = "toggle",
							name = "Rebirth",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_REZ
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_REZ = value
							end,
						},	
						DRU_INNERV = {
							type = "toggle",
							name = "Innervate",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_INNERV
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_INNERV = value
							end,
						},
						DRU_BAR = {
							type = "toggle",
							name = "Barkskin",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_BAR
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_BAR = value
							end,
						},
						DRU_MOU = {
							type = "toggle",
							name = "Might of Ursoc",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_MOU
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_MOU = value
							end,
						},
						DRU_RENEW = {
							type = "toggle",
							name = "Renewal",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_RENEW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_RENEW = value
							end,
						},
						DRU_SI = {
							type = "toggle",
							name = "Survival Instincts",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DRU_SI
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DRU_SI = value
							end,
						},
					},
				},
				shaman = {
					type = "group",
					name = "Shaman Cooldowns",
					order = 2,
					args ={
						SHA_SLT = {
							type = "toggle",
							name = "Spirit Link Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_SLT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_SLT = value
							end,
						},		
						SHA_MTT = {
							type = "toggle",
							name = "Mana Tide Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_MTT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_MTT = value
							end,
						},		
						SHA_HTT = {
							type = "toggle",
							name = "Healing Tide Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_HTT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_HTT = value
							end,
						},		
						SHA_ST = {
							type = "toggle",
							name = "Stormlash Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_ST
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_ST = value
							end,
						},
						SHA_FET = {
							type = "toggle",
							name = "Fire Elemental Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_FET
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_FET = value
							end,
						},	
						SHA_RE = {
							type = "toggle",
							name = "Reincarnation",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_RE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_RE = value
							end,
						},	
						SHA_COTE = {
							type = "toggle",
							name = "Call of the Elements",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_COTE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_COTE = value
							end,
						},
						SHA_ASC = {
							type = "toggle",
							name = "Ascendance",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_ASC
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_ASC = value
							end,
						},
						SHA_ASHIFT = {
							type = "toggle",
							name = "Astral Shift",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_ASHIFT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_ASHIFT = value
							end,
						},
						SHA_SBTOT = {
							type = "toggle",
							name = "Stone Bulwark Totem",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_SBTOT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_SBTOT = value
							end,
						},	
						SHA_SRAGE = {
							type = "toggle",
							name = "Shamanistic Rage",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.SHA_SRAGE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.SHA_SRAGE = value
							end,
						},	
					},
				},
				monk = {
					type = "group",
					name = "Monk Cooldowns",
					order = 2,
					args ={
						MON_ZEN = {
							type = "toggle",
							name = "Zen Meditation",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_ZEN
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_ZEN = value
							end,
						},	
						MON_LIFE = {
							type = "toggle",
							name = "Life Cocoon",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_LIFE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_LIFE = value
							end,
						},	
						MON_REV = {
							type = "toggle",
							name = "Revival",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_REV
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_REV = value
							end,
						},
						MON_AHARM = {
							type = "toggle",
							name = "Avert Harm",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_AHARM
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_AHARM = value
							end,
						},
						MON_FBREW = {
							type = "toggle",
							name = "Fortifying Brew",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_FBREW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_FBREW = value
							end,
						},	
						MON_DHARM = {
							type = "toggle",
							name = "Dampen Harm",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_DHARM
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_DHARM = value
							end,
						},
						MON_DMAG = {
							type = "toggle",
							name = "Diffuse Magic",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_DMAG
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_DMAG = value
							end,
						},
						MON_TOKAR = {
							type = "toggle",
							name = "Touch of Karma",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MON_TOKAR
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MON_TOKAR = value
							end,
						},
					},
				},
				warlock = {
					type = "group",
					name = "Warlock Cooldowns",
					order = 2,
					args ={
						LOC_SR = {
							type = "toggle",
							name = "Soulstone Resurrection",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_SR
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_SR = value
							end,
						},
						LOC_TWARD = {
							type = "toggle",
							name = "Twilight Ward",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_TWARD
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_TWARD = value
							end,
						},
						LOC_URESOLVE = {
							type = "toggle",
							name = "Unending Resolve",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_URESOLVE
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_URESOLVE = value
							end,
						},
						LOC_DREGEN = {
							type = "toggle",
							name = "Dark Regeneration",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_DREGEN
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_DREGEN = value
							end,
						},
						LOC_DBARGAIN = {
							type = "toggle",
							name = "Dark Bargain",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_DBARGAIN
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_DBARGAIN = value
							end,
						},
						LOC_SPACT = {
							type = "toggle",
							name = "Dark Bargain",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.LOC_SPACT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.LOC_SPACT = value
							end,
						},
					},
				},
				DK = {
					type = "group",
					name = "Death Knight Cooldowns",
					order = 2,
					args ={
						DEA_RA = {
							type = "toggle",
							name = "Raise Ally",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_RA
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_RA = value
							end,
						},
						DEA_AMZ = {
							type = "toggle",
							name = "Anti-Magic Zone",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_AMZ
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_AMZ = value
							end,
						},
						DEA_GG = {
							type = "toggle",
							name = "Gorefiend's Grasp",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_GG
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_GG = value
							end,
						},
						DEA_RW = {
							type = "toggle",
							name = "Remorseless Winter",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_RW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_RW = value
							end,
						},
						DEA_IBF = {
							type = "toggle",
							name = "Icebound Fortitude",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_IBF
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_IBF = value
							end,
						},
						DEA_AOTD = {
							type = "toggle",
							name = "Army of the Dead",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_AOTD
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_AOTD = value
							end,
						},
						DEA_AMS = {
							type = "toggle",
							name = "Anti-Magic Shell",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_AMS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_AMS = value
							end,
						},
						DEA_DP = {
							type = "toggle",
							name = "Death Pact",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_DP
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_DP = value
							end,
						},
						DEA_BS = {
							type = "toggle",
							name = "Bone Shield",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_BS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_BS = value
							end,
						},
						DEA_DRW = {
							type = "toggle",
							name = "Dancing Rune Weapond",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_DRW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_DRW = value
							end,
						},
						DEA_RT = {
							type = "toggle",
							name = "Rune Tap",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_RT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_RT = value
							end,
						},
						DEA_VB = {
							type = "toggle",
							name = "Vampiric Blood",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.DEA_VB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.DEA_VB = value
							end,
						},
					},
				},
				Rogue = {
					type = "group",
					name = "Rogue Cooldowns",
					order = 2,
					args ={
						ROG_SB = {
							type = "toggle",
							name = "Smoke Bomb",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.ROG_SB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.ROG_SB = value
							end,
						},
						ROG_TOT = {
							type = "toggle",
							name = "Tricks of the Trade",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.ROG_TOT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.ROG_TOT = value
							end,
						},
						ROG_FEINT = {
							type = "toggle",
							name = "Feint",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.ROG_FEINT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.ROG_FEINT = value
							end,
						},
					},
				},
				Mage = {
					type = "group",
					name = "Rogue Cooldowns",
					order = 2,
					args ={
						MAG_IB = {
							type = "toggle",
							name = "Ice Block",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_IB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_IB = value
							end,
						},
						MAG_AT = {
							type = "toggle",
							name = "Alter Time",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_AT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_AT = value
							end,
						},
						MAG_IBAR = {
							type = "toggle",
							name = "Ice Barrier",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_IBAR
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_IBAR = value
							end,
						},
						MAG_TS = {
							type = "toggle",
							name = "Temporal Shield",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_TS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_TS = value
							end,
						},
						MAG_GI = {
							type = "toggle",
							name = "Greater Invisibility",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_GI
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_GI = value
							end,
						},
						MAG_IW = {
							type = "toggle",
							name = "Incanter's Ward",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.MAG_IW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.MAG_IW = value
							end,
						},
					},
				},
				Mage = {
					type = "group",
					name = "Rogue Cooldowns",
					order = 2,
					args ={
						HUN_DET = {
							type = "toggle",
							name = "Deterrence",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.HUN_DET
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.HUN_DET = value
							end,
						},
						HUN_EX = {
							type = "toggle",
							name = "Exhilaration",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.HUN_EX
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.HUN_EX = value
							end,
						},
					},
				},
				Warrior = {
					type = "group",
					name = "Warrior Cooldowns",
					order = 2,
					args ={
						WAR_RC = {
							type = "toggle",
							name = "Rallying Cry",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_RC
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_RC = value
							end,
						},
						WAR_DB = {
							type = "toggle",
							name = "Demoralizing Banner",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_DB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_DB = value
							end,
						},
						WAR_STH = {
							type = "toggle",
							name = "Shattering Throw",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_STH
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_STH = value
							end,
						},
						WAR_SB = {
							type = "toggle",
							name = "Skull Banner",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_SB
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_SB = value
							end,
						},
						WAR_VIGI = {
							type = "toggle",
							name = "Vigilance",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_VIGI
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_VIGI = value
							end,
						},
						WAR_SGUARD = {
							type = "toggle",
							name = "Safeguard",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_SGUARD
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_SGUARD = value
							end,
						},
						WAR_DSHOUT = {
							type = "toggle",
							name = "Demoralizing Shout",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_DSHOUT
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_DSHOUT = value
							end,
						},
						WAR_SWALL = {
							type = "toggle",
							name = "Shield Wall",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_WAR_SWALL
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_WAR_SWALL = value
							end,
						},
						WAR_DBTW = {
							type = "toggle",
							name = "Die by the Sword",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_DBTW
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_DBTW = value
							end,
						},
						WAR_LSTAND = {
							type = "toggle",
							name = "Last Stand",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_LSTAND
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_LSTAND = value
							end,
						},
						WAR_EREGEN = {
							type = "toggle",
							name = "Last Stand",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.WAR_EREGEN
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.WAR_EREGEN = value
							end,
						},
					},
				},
				Everybody = {
					type = "group",
					name = "Everybody Cooldowns",
					order = 2,
					args ={
						ALL_HS = {
							type = "toggle",
							name = "HealthStone",
							order = 1,
							get = function()
								return BLRCD.profileDB.cooldown.ALL_HS
							end,
							set = function(key, value)
								BLRCD.profileDB.cooldown.ALL_HS = value
							end,
						},
					},
				},
			},
		},
		displaycfg = {
			order = 3,
			type = "group",
			name = "Display Settings",
			cmdInline = true,
			args = {
				configure = {
					type = "execute",
					name = "Apply Changes",
					desc = "Apply the changes to the active cooldowns and reload the UI.",
					func = function()
						ReloadUI()
					end,
					order = 1,
					width = "full",
				},
				MSG_DISPLAY = {
					order = 1,
					type = "header",
					name = "Display Group",
				},
				AOE_HEAL = {
					type = "toggle",
					name = "AOE_HEA",
					order = 3,
					get = function()
						return BLRCD.profileDB.display.AOE_HEAL
					end,
					set = function(key, value)
						BLRCD.profileDB.display.AOE_HEAL = value
					end,
				},
				SINGLE_HEAL = {
					type = "toggle",
					name = "SINGLE_HEAL",
					order = 4,
					get = function()
						return BLRCD.profileDB.display.SINGLE_HEAL
					end,
					set = function(key, value)
						BLRCD.profileDB.display.SINGLE_HEAL = value
					end,
				},
				AOE_DPS = {
					type = "toggle",
					name = "AOE_DPS",
					order = 5,
					get = function()
						return BLRCD.profileDB.display.AOE_DPS
					end,
					set = function(key, value)
						BLRCD.profileDB.display.AOE_DPS = value
					end,
				},
				MANA_REGEN = {
					type = "toggle",
					name = "MANA_REGEN",
					order = 6,
					get = function()
						return BLRCD.profileDB.display.MANA_REGEN
					end,
					set = function(key, value)
						BLRCD.profileDB.display.MANA_REGEN = value
					end,
				},
				REZ = {
					type = "toggle",
					name = "REZ",
					order = 7,
					get = function()
						return BLRCD.profileDB.display.REZ
					end,
					set = function(key, value)
						BLRCD.profileDB.display.REZ = value
					end,
				},
				DEFENSIVE = {
					type = "toggle",
					name = "DEFENSIVE",
					order = 8,
					get = function()
						return BLRCD.profileDB.display.DEFENSIVE
					end,
					set = function(key, value)
						BLRCD.profileDB.display.DEFENSIVE = value
					end,
				},
				MISC = {
					type = "toggle",
					name = "MISC",
					order = 9,
					get = function()
						return BLRCD.profileDB.display.MISC
					end,
					set = function(key, value)
						BLRCD.profileDB.display.MISC = value
					end,
				},
				MSG_OTHER = {
					order = 10,
					type = "header",
					name = "Other Option",
				},
				CD_BAR = {
					type = "toggle",
					name = "Cooldown Bar",
					order = 11,
					get = function()
						return BLRCD.profileDB.display.CD_BAR
					end,
					set = function(key, value)
						BLRCD.profileDB.display.CD_BAR = value
					end,
				},
				scale = {
					order = 12,
					type = "range",
					name = 'Set Scale',
					desc = "Sets Scale of Raid Cooldowns",
					min = 0.3, max = 2, step = 0.01,
					get = function()
						return BLRCD.profileDB.scale 
					end,
					set = function(info, value)
						BLRCD.profileDB.scale = value;
						BLRCD:Scale();
					end,
				},	
				grow = {
					order = 13,
					name = "Bar Grow Direction",
					type = 'select',
					get = function()
						return BLRCD.profileDB.growth 
					end,
					set = function(info, value)
						BLRCD.profileDB.growth = value
					end,
					values = {
						['left'] = "Left",
						['right'] = "Right",
					},			
				},
				minimap = {
					type = "toggle",
					name = "Show minimap button",
					desc = "Show the BLTRCD minimap button",
					order = 14,
					get = function() 
						return not BLRCD.profileDB.minimap.hide 
					end,
					set = function(key, value)
						BLRCD.profileDB.minimap.hide = not value
						if value then LDBIcon:Show("BLTRCD") else LDBIcon:Hide("BLTRCD") end
					end,
--					hidden = function() return not LDBIconRegistered end,
				},				
			},
		},
	},
}---------------------------------------------------